==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshow_user_and_ip-2.2.2.tar.gz: show_user_and_ip/functions.php <==
<?php

function show_ui()
{
  global $username, $show_left_username_ip;

  if( $show_left_username_ip == 1 ) {
    include_once('../functions/i18n.php');
    bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    echo '<p><div align="center">';
    echo '<hr>';
    echo '<strong>' . _("Your username:") . '</strong><br>';
    echo $username;
    echo '<br><br>';
    echo '<strong>' . _("Your IP address:") . '</strong><br>';
    echo $_SERVER['REMOTE_ADDR'];
    echo '<hr>';
    echo '</div></p>';
    bindtextdomain('squirrelmail', '../locale');
    textdomain('squirrelmail');
  }
}

function last_load() {
  global $username, $data_dir, $my_last_ip, $my_last_date, $my_page_first_shown, $show_left_username_ip;
  $my_page_first_shown = getPref($data_dir, $username, 'my_page_first_shown');
  $my_last_ip = getPref($data_dir, $username, 'my_last_ip');
  $my_last_date = getPref($data_dir, $username, 'my_last_date');
  $show_left_username_ip = getPref($data_dir, $username, 'show_username_and_ip_on_left');
  if ( strlen($show_left_username_ip) == 0 ) $show_left_username_ip = 0;
}

function show_last() {
  global $color, $my_last_ip, $my_last_date, $my_page_first_shown, $username;

  if ( $my_page_first_shown == 1 ) {
    $my_display_format = _("D, F j, Y G:i");
    $my_display_date = date(_("D, F j, Y G:i"), $my_last_date);

    if ( !strpos($my_display_format, "F") === false ) {    
      $my_display_date = str_replace("January", _("January"), $my_display_date);
      $my_display_date = str_replace("February", _("February"), $my_display_date);
      $my_display_date = str_replace("March", _("March"), $my_display_date);
      $my_display_date = str_replace("April", _("April"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("June", _("June"), $my_display_date);
      $my_display_date = str_replace("July", _("July"), $my_display_date);
      $my_display_date = str_replace("August", _("August"), $my_display_date);
      $my_display_date = str_replace("September", _("September"), $my_display_date);
      $my_display_date = str_replace("October", _("October"), $my_display_date);
      $my_display_date = str_replace("November", _("November"), $my_display_date);
      $my_display_date = str_replace("December", _("December"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "M") === false ) {    
      $my_display_date = str_replace("Jan", _("Jan"), $my_display_date);
      $my_display_date = str_replace("Feb", _("Feb"), $my_display_date);
      $my_display_date = str_replace("Mar", _("Mar"), $my_display_date);
      $my_display_date = str_replace("Apr", _("Apr"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("Jun", _("Jun"), $my_display_date);
      $my_display_date = str_replace("Jul", _("Jul"), $my_display_date);
      $my_display_date = str_replace("Aug", _("Aug"), $my_display_date);
      $my_display_date = str_replace("Sep", _("Sep"), $my_display_date);
      $my_display_date = str_replace("Oct", _("Oct"), $my_display_date);
      $my_display_date = str_replace("Nov", _("Nov"), $my_display_date);
      $my_display_date = str_replace("Dec", _("Dec"), $my_display_date);
    }
    
    if ( !strpos($my_display_format, "l") === false ) {
      $my_display_date = str_replace("Monday", _("Monday"), $my_display_date);
      $my_display_date = str_replace("Tuesday", _("Tuesday"), $my_display_date);
      $my_display_date = str_replace("Wednesday", _("Wednesday"), $my_display_date);
      $my_display_date = str_replace("Thursday", _("Thursday"), $my_display_date);
      $my_display_date = str_replace("Friday", _("Friday"), $my_display_date);
      $my_display_date = str_replace("Saturday", _("Saturday"), $my_display_date);
      $my_display_date = str_replace("Sunday", _("Sunday"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "D") === false ) {
      $my_display_date = str_replace("Mon", _("Mon"), $my_display_date);
      $my_display_date = str_replace("Tue", _("Tue"), $my_display_date);
      $my_display_date = str_replace("Wed", _("Wed"), $my_display_date);
      $my_display_date = str_replace("Thu", _("Thu"), $my_display_date);
      $my_display_date = str_replace("Fri", _("Fri"), $my_display_date);
      $my_display_date = str_replace("Sat", _("Sat"), $my_display_date);
      $my_display_date = str_replace("Sun", _("Sun"), $my_display_date);
    }
   
    echo "<br><table align=center width=\"70%\" cellpadding=0 cellspacing=3 border=0 bgcolor=\"$color[9]\">";
    echo '<tr><td>';
    echo "<table width=\"100%\" cellpadding=5 cellspacing=1 border=0 bgcolor=\"$color[4]\">";
    echo "<tr><td align=center>"; 
    include_once('../functions/i18n.php');
    bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    echo _("Welcome") . "<strong> $username</strong>, ";
    echo _("your last connection was from ");
    echo "<strong>$my_last_ip</strong><br>";
    echo _("on");

    bindtextdomain('squirrelmail', '../locale');
    textdomain('squirrelmail');
    echo " <strong> $my_display_date</strong>.";

    echo '</td></tr></table></td></tr></table>';
  }
}

function left_opt() {
  global $show_left_username_ip;

  include_once('../functions/i18n.php');
  bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
  textdomain('show_user_and_ip');

  echo '<tr><td align="right" nowrap valign="top">' . _("Show My Username and IP under Folders List:");

  bindtextdomain('squirrelmail', '../locale');
  textdomain('squirrelmail');
  echo '</td><td>';
  echo '<label><input type="radio" name="check_show_left_username_ip" value="1"';

  if ( $show_left_username_ip == 1) echo ' CHECKED';
  echo '>&nbsp;' . _("Yes") . '</label>&nbsp;&nbsp;&nbsp;&nbsp;';
  echo '<label><input type="radio" name="check_show_left_username_ip"';
  if ( $show_left_username_ip == 0) echo ' CHECKED';
  echo '>&nbsp;' . _("No") . '</label></td></tr>';
}

function left_opt_save() {
  global $username, $data_dir;
  if ( $_POST['check_show_left_username_ip'] == 0 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "0");
  }
  elseif ( $_POST['check_show_left_username_ip'] == 1 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "1");
  }
}

function last_save() {
  global $username, $data_dir, $my_page_first_shown;
  if( $my_page_first_shown == 1 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "0"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
}

function reset_fl() {
  global $username, $data_dir, $my_last_date;
  if( strlen($my_last_date) == 0 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
  else {
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
  }
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshow_user_and_ip-2.2.3.tar.gz: show_user_and_ip/functions.php <==
<?php

function show_ui()
{
  global $username, $show_left_username_ip;

  if( $show_left_username_ip == 1 ) {
    include_once(SM_PATH . 'functions/i18n.php');
    bindtextdomain('show_user_and_ip', SM_PATH . 'plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    echo '<p><div align="center">';
    echo '<hr>';
    echo '<strong>' . _("Your username:") . '</strong><br>';
    echo $username;
    echo '<br><br>';
    echo '<strong>' . _("Your IP address:") . '</strong><br>';
    echo $_SERVER['REMOTE_ADDR'];
    echo '<hr>';
    echo '</div></p>';
    bindtextdomain('squirrelmail', SM_PATH . 'locale');
    textdomain('squirrelmail');
  }
}

function last_load() {
  global $username, $data_dir, $my_last_ip, $my_last_date, $my_page_first_shown, $show_left_username_ip;
  $my_page_first_shown = getPref($data_dir, $username, 'my_page_first_shown');
  $my_last_ip = getPref($data_dir, $username, 'my_last_ip');
  $my_last_date = getPref($data_dir, $username, 'my_last_date');
  $show_left_username_ip = getPref($data_dir, $username, 'show_username_and_ip_on_left');
  if ( strlen($show_left_username_ip) == 0 ) $show_left_username_ip = 0;
}

function show_last() {
  global $color, $my_last_ip, $my_last_date, $my_page_first_shown, $username;

  if ( $my_page_first_shown == 1 ) {
    $my_display_format = _("D, F j, Y G:i");
    $my_display_date = date(_("D, F j, Y G:i"), $my_last_date);

    if ( !strpos($my_display_format, "F") === false ) {    
      $my_display_date = str_replace("January", _("January"), $my_display_date);
      $my_display_date = str_replace("February", _("February"), $my_display_date);
      $my_display_date = str_replace("March", _("March"), $my_display_date);
      $my_display_date = str_replace("April", _("April"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("June", _("June"), $my_display_date);
      $my_display_date = str_replace("July", _("July"), $my_display_date);
      $my_display_date = str_replace("August", _("August"), $my_display_date);
      $my_display_date = str_replace("September", _("September"), $my_display_date);
      $my_display_date = str_replace("October", _("October"), $my_display_date);
      $my_display_date = str_replace("November", _("November"), $my_display_date);
      $my_display_date = str_replace("December", _("December"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "M") === false ) {    
      $my_display_date = str_replace("Jan", _("Jan"), $my_display_date);
      $my_display_date = str_replace("Feb", _("Feb"), $my_display_date);
      $my_display_date = str_replace("Mar", _("Mar"), $my_display_date);
      $my_display_date = str_replace("Apr", _("Apr"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("Jun", _("Jun"), $my_display_date);
      $my_display_date = str_replace("Jul", _("Jul"), $my_display_date);
      $my_display_date = str_replace("Aug", _("Aug"), $my_display_date);
      $my_display_date = str_replace("Sep", _("Sep"), $my_display_date);
      $my_display_date = str_replace("Oct", _("Oct"), $my_display_date);
      $my_display_date = str_replace("Nov", _("Nov"), $my_display_date);
      $my_display_date = str_replace("Dec", _("Dec"), $my_display_date);
    }
    
    if ( !strpos($my_display_format, "l") === false ) {
      $my_display_date = str_replace("Monday", _("Monday"), $my_display_date);
      $my_display_date = str_replace("Tuesday", _("Tuesday"), $my_display_date);
      $my_display_date = str_replace("Wednesday", _("Wednesday"), $my_display_date);
      $my_display_date = str_replace("Thursday", _("Thursday"), $my_display_date);
      $my_display_date = str_replace("Friday", _("Friday"), $my_display_date);
      $my_display_date = str_replace("Saturday", _("Saturday"), $my_display_date);
      $my_display_date = str_replace("Sunday", _("Sunday"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "D") === false ) {
      $my_display_date = str_replace("Mon", _("Mon"), $my_display_date);
      $my_display_date = str_replace("Tue", _("Tue"), $my_display_date);
      $my_display_date = str_replace("Wed", _("Wed"), $my_display_date);
      $my_display_date = str_replace("Thu", _("Thu"), $my_display_date);
      $my_display_date = str_replace("Fri", _("Fri"), $my_display_date);
      $my_display_date = str_replace("Sat", _("Sat"), $my_display_date);
      $my_display_date = str_replace("Sun", _("Sun"), $my_display_date);
    }
   
    echo "<br><table align=center width=\"70%\" cellpadding=0 cellspacing=3 border=0 bgcolor=\"$color[9]\">";
    echo '<tr><td>';
    echo "<table width=\"100%\" cellpadding=5 cellspacing=1 border=0 bgcolor=\"$color[4]\">";
    echo "<tr><td align=center>"; 
    include_once(SM_PATH . 'functions/i18n.php');
    bindtextdomain('show_user_and_ip', SM_PATH . 'plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    echo _("Welcome") . "<strong> $username</strong>, ";
    echo _("your last connection was from ");
    echo "<strong>$my_last_ip</strong><br>";
    echo _("on");

    bindtextdomain('squirrelmail', SM_PATH . 'locale');
    textdomain('squirrelmail');
    echo " <strong> $my_display_date</strong>.";

    echo '</td></tr></table></td></tr></table>';
  }
}

function left_opt() {
  global $show_left_username_ip;

  include_once(SM_PATH . 'functions/i18n.php');
  bindtextdomain('show_user_and_ip', SM_PATH . 'plugins/show_user_and_ip/locale');
  textdomain('show_user_and_ip');

  echo '<tr><td align="right" nowrap valign="top">' . _("Show My Username and IP under Folders List:");

  bindtextdomain('squirrelmail', SM_PATH . 'locale');
  textdomain('squirrelmail');
  echo '</td><td>';
  echo '<label><input type="radio" name="check_show_left_username_ip" value="1"';

  if ( $show_left_username_ip == 1) echo ' CHECKED';
  echo '>&nbsp;' . _("Yes") . '</label>&nbsp;&nbsp;&nbsp;&nbsp;';
  echo '<label><input type="radio" name="check_show_left_username_ip"';
  if ( $show_left_username_ip == 0) echo ' CHECKED';
  echo '>&nbsp;' . _("No") . '</label></td></tr>';
}

function left_opt_save() {
  global $username, $data_dir;
  if ( $_POST['check_show_left_username_ip'] == 0 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "0");
  }
  elseif ( $_POST['check_show_left_username_ip'] == 1 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "1");
  }
}

function last_save() {
  global $username, $data_dir, $my_page_first_shown;
  if( $my_page_first_shown == 1 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "0"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
}

function reset_fl() {
  global $username, $data_dir, $my_last_date;
  if( strlen($my_last_date) == 0 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
  else {
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
  }
}

?>
